execute_create_pool_instance

Function execute_create_pool_instance 

pub fn execute_create_pool_instance(
    deps: DepsMut<'_>,
    env: Env,
    info: MessageInfo,
    pool_type: PoolType,
    asset_infos: Vec<AssetInfo>,
    native_asset_precisions: Vec<NativeAssetPrecisionInfo>,
    fee_info: Option<FeeInfo>,
    init_params: Option<Binary>,
) -> Result<Response, ContractError>
Description - Creates a new pool with the specified parameters in the asset_infos variable. Returns an ContractError on failure or

returns the address of the contract if the creation was successful.

Params

  • pool_type is the object of type PoolType.
  • asset_infos is a vector consisting of type AssetInfo.
  • lp_token_name is the name of the LP token to be used for instantiating new LP tokens along-with the Pools.
  • lp_token_symbol is the symbol of the LP token to be used for instantiating new LP tokens along-with the Pools.
  • init_params is the object of type Binary which contains any custom params required by the Pool instance for its initialization.